@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License
    along with Strawberry.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ */
 
 #ifndef FHT_H
 #define FHT_H
@@ -55,20 +55,20 @@ class FHT {
   /**
    * Recursive in-place Hartley transform. For internal use only!
    */
-  void _transform(float*, int, int);
+  void _transform(float *p, int n, int k);
 
  public:
   /**
-  * Prepare transform for data sets with @f$2^n@f$ numbers, whereby @f$n@f$
-  * should be at least 3. Values of more than 3 need a trigonometry table.
-  * @see makeCasTable()
-  */
+   * Prepare transform for data sets with @f$2^n@f$ numbers, whereby @f$n@f$
+   * should be at least 3. Values of more than 3 need a trigonometry table.
+   * @see makeCasTable()
+   */
   explicit FHT(uint);
 
   ~FHT();
   int sizeExp() const;
   int size() const;
-  void scale(float*, float) const;
+  void scale(float *p, float d) const;
 
   /**
    * Exponentially Weighted Moving Average (EWMA) filter.
@@ -90,12 +90,12 @@ class FHT {
   /**
    * Semi-logarithmic audio spectrum.
    */
-  void semiLogSpectrum(float*);
+  void semiLogSpectrum(float *p);
 
   /**
    * Fourier spectrum.
    */
-  void spectrum(float*);
+  void spectrum(float *p);
 
   /**
    * Calculates a mathematically correct FFT power spectrum.
@@ -103,7 +103,7 @@ class FHT {
    * and factor the 0.5 in the final scaling factor.
    * @see FHT::power2()
    */
-  void power(float*);
+  void power(float *p);
 
   /**
    * Calculates an FFT power spectrum with doubled values as a
@@ -112,14 +112,14 @@ class FHT {
    * of @f$2^n@f$ input values. This is the fastest transform.
    * @see FHT::power()
    */
-  void power2(float*);
+  void power2(float *p);
 
   /**
    * Discrete Hartley transform of data sets with 8 values.
    */
-  static void transform8(float*);
+  static void transform8(float *p);
 
-  void transform(float*);
+  void transform(float *p);
 };
 
 #endif  // FHT_H
