@@ -35,7 +35,7 @@
 #include <QList>
 #include <QImage>
 
-#include "shared_ptr.h"
+#include "includes/shared_ptr.h"
 #include "song.h"
 
 class MusicStorage {
@@ -57,7 +57,7 @@ class MusicStorage {
     Transcode_Unsupported = 3,
   };
 
-  using ProgressFunction = std::function<void(float progress)>;
+  using ProgressFunction = std::function<void (float progress)>;
 
   struct CopyJob {
     CopyJob() : overwrite_(false), remove_original_(false), albumcover_(false) {}
