@@ -39,9 +39,6 @@ class Windows7ThumbBar : public QObject {
   // Creates a list of buttons in the taskbar icon for this window.
   explicit Windows7ThumbBar(QWidget *widget = nullptr);
 
-  static const int kIconSize;
-  static const int kMaxButtonCount;
-
   // You must call this in the parent widget's constructor before returning to the event loop.  If an action is nullptr it becomes a spacer.
   void SetActions(const QList<QAction*> &actions);
 
@@ -52,7 +49,7 @@ class Windows7ThumbBar : public QObject {
   ITaskbarList3 *CreateTaskbarList();
   void SetupButton(const QAction *action, THUMBBUTTON *button);
 
- private slots:
+ private Q_SLOTS:
   void ActionChangedTriggered();
   void ActionChanged();
 
