@@ -38,10 +38,10 @@
 #include <QJsonArray>
 #include <QJsonObject>
 
-#include "core/scoped_ptr.h"
-#include "core/shared_ptr.h"
+#include "includes/scoped_ptr.h"
+#include "includes/shared_ptr.h"
+#include "includes/dbus_metatypes.h"
 
-#include "dbus/metatypes.h"
 #include "devicelister.h"
 
 class OrgFreedesktopDBusObjectManagerInterface;
