@@ -127,8 +127,9 @@ QString About::MainHtml() const {
   ret += "<p>"_L1;
   ret += tr("If you like Strawberry and can make use of it, consider sponsoring or donating.");
   ret += "<br />"_L1;
-  ret += tr("You can sponsor the author on %1. You can also make a one-time payment through %2.").arg(
-    QStringLiteral("<a style=\"color:%1;\" href=\"https://github.com/sponsors/jonaski\">GitHub sponsors</a>").arg(palette().text().color().name()),
+  ret += tr("You can sponsor the author on %1 or %2. You can also make a one-time payment through %3.").arg(
+    QStringLiteral("<a style=\"color:%1;\" href=\"https://www.patreon.com/jonaskvinge\">Patreon</a>").arg(palette().text().color().name()),
+    QStringLiteral("<a style=\"color:%1;\" href=\"https://github.com/sponsors/jonaski\">GitHub</a>").arg(palette().text().color().name()),
     QStringLiteral("<a style=\"color:%1;\" href=\"https://paypal.me/jonaskvinge\">paypal.me/jonaskvinge</a>").arg(palette().text().color().name())
   );
 
