@@ -31,20 +31,25 @@
 
 #include "ui_console.h"
 
-class Application;
+#include "includes/shared_ptr.h"
+
+class Database;
 
 class Console : public QDialog {
   Q_OBJECT
 
  public:
-  explicit Console(Application *app, QWidget *parent = nullptr);
+  explicit Console(const SharedPtr<Database> database, QWidget *parent = nullptr);
 
  private Q_SLOTS:
   void RunQuery();
 
+ Q_SIGNALS:
+  void Error(const QString &error);
+
  private:
   Ui::Console ui_;
-  Application *app_;
+  const SharedPtr<Database> database_;
 };
 
 #endif  // CONSOLE_H
