@@ -71,6 +71,7 @@
 #include <QSettings>
 #include <QMimeData>
 
+#include "constants/timeconstants.h"
 #include "core/iconloader.h"
 #include "core/logging.h"
 #include "core/settings.h"
@@ -1520,7 +1521,7 @@ void EditTagDialog::FetchLyrics() {
   const Song song = data_.value(ui_->song_list->selectionModel()->selectedIndexes().first().row()).current_;
   lyrics_fetcher_->Clear();
   ui_->lyrics->setPlainText(tr("loading..."));
-  lyrics_id_ = static_cast<qint64>(lyrics_fetcher_->Search(song.effective_albumartist(), song.artist(), song.album(), song.title()));
+  lyrics_id_ = static_cast<qint64>(lyrics_fetcher_->Search(song.effective_albumartist(), song.artist(), song.album(), song.title(), song.length_nanosec() / kNsecPerSec));
 
 }
 
