@@ -1,5 +1,6 @@
 /*
  * Strawberry Music Player
+ * Copyright 2025, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,7 +106,7 @@ void RichPresence::CurrentSongChanged(const Song &song) {
 
   SetTimestamp(0LL);
   activity_.length_secs = song.length_nanosec() / kNsecPerSec;
-  activity_.title = song.title();
+  activity_.title = song.PrettyTitle();
   activity_.artist = song.artist();
   activity_.album = song.album();
 
