@@ -1,24 +1,24 @@
 /***************************************************************************
- *   Copyright (C) 2003-2005 by Mark Kretschmann <markey@web.de>           *
- *   Copyright (C) 2005 by Jakub Stachowski <qbast@go2.pl>                 *
- *   Copyright (C) 2006 Paul Cifarelli <paul@cifarelli.net>                *
- *   Copyright (C) 2017-2024 Jonas Kvinge <jonas@jkvinge.net>              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Steet, Fifth Floor, Boston, MA  02111-1307, USA.          *
- ***************************************************************************/
+*   Copyright (C) 2003-2005 by Mark Kretschmann <markey@web.de>           *
+*   Copyright (C) 2005 by Jakub Stachowski <qbast@go2.pl>                 *
+*   Copyright (C) 2006 Paul Cifarelli <paul@cifarelli.net>                *
+*   Copyright (C) 2017-2024 Jonas Kvinge <jonas@jkvinge.net>              *
+*                                                                         *
+*   This program is free software; you can redistribute it and/or modify  *
+*   it under the terms of the GNU General Public License as published by  *
+*   the Free Software Foundation; either version 2 of the License, or     *
+*   (at your option) any later version.                                   *
+*                                                                         *
+*   This program is distributed in the hope that it will be useful,       *
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+*   GNU General Public License for more details.                          *
+*                                                                         *
+*   You should have received a copy of the GNU General Public License     *
+*   along with this program; if not, write to the                         *
+*   Free Software Foundation, Inc.,                                       *
+*   51 Franklin Steet, Fifth Floor, Boston, MA  02111-1307, USA.          *
+***************************************************************************/
 
 #include "config.h"
 
@@ -632,7 +632,10 @@ void GstEngine::HandlePipelineError(const int pipeline_id, const int domain, con
   qLog(Error) << "GStreamer error:" << domain << error_code << message;
 
   Q_EMIT Error(message);
-  Q_EMIT Error(debugstr);
+
+  if (!debugstr.isEmpty()) {
+    Q_EMIT Error(debugstr);
+  }
 
   if (fadeout_pause_pipeline_ && pipeline_id == fadeout_pause_pipeline_->id()) {
     StopFadeoutPause();
@@ -671,7 +674,7 @@ void GstEngine::HandlePipelineError(const int pipeline_id, const int domain, con
 
 void GstEngine::NewMetaData(const int pipeline_id, const EngineMetadata &engine_metadata) {
 
-  if (!current_pipeline_|| current_pipeline_->id() != pipeline_id) return;
+  if (!current_pipeline_ || current_pipeline_->id() != pipeline_id) return;
   Q_EMIT MetaData(engine_metadata);
 
 }
@@ -1061,8 +1064,7 @@ void GstEngine::UpdateScope(const int chunk_length) {
       buffer_format_.startsWith("S24LE"_L1) ||
       buffer_format_.startsWith("S24_32LE"_L1) ||
       buffer_format_.startsWith("S32LE"_L1) ||
-      buffer_format_.startsWith("F32LE"_L1)
-  ) {
+      buffer_format_.startsWith("F32LE"_L1)) {
     memcpy(dest, source, bytes);
   }
   else {
