@@ -43,7 +43,7 @@ using namespace Qt::Literals::StringLiterals;
   DEFINE_GUID(CLSID_MMDeviceEnumerator, 0xbcde0395, 0xe52f, 0x467c, 0x8e, 0x3d, 0xc4, 0x57, 0x92, 0x91, 0x69, 0x2e);
 #endif
 
-MMDeviceFinder::MMDeviceFinder() : DeviceFinder(u"mmdevice"_s, { u"wasapisink"_s }) {}
+MMDeviceFinder::MMDeviceFinder() : DeviceFinder(u"mmdevice"_s, { u"wasapisink"_s, u"wasapi2sink"_s }) {}
 
 EngineDeviceList MMDeviceFinder::ListDevices() {
 
