@@ -80,7 +80,7 @@ using namespace Qt::Literals::StringLiterals;
 namespace {
 constexpr char kSettingsGroup[] = "OrganizeDialog";
 constexpr char kDefaultFormat[] = "%albumartist/%album{ (Disc %disc)}/{%track - }{%albumartist - }%album{ (Disc %disc)} - %title.%extension";
-}
+}  // namespace
 
 OrganizeDialog::OrganizeDialog(const SharedPtr<TaskManager> task_manager,
                                const SharedPtr<TagReaderClient> tagreader_client,
@@ -499,8 +499,8 @@ void OrganizeDialog::UpdatePreviews() {
   }
 
   // Update the free space bar
-  quint64 capacity = destination.data(MusicStorage::Role_Capacity).toLongLong();
-  quint64 free = destination.data(MusicStorage::Role_FreeSpace).toLongLong();
+  quint64 capacity = destination.data(MusicStorage::Role_Capacity).toULongLong();
+  quint64 free = destination.data(MusicStorage::Role_FreeSpace).toULongLong();
 
   if (capacity > 0) {
     ui_->free_space->show();
