@@ -2,7 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
- * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2018-2024, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,18 +28,9 @@ class PlaylistListSortFilterModel : public QSortFilterProxyModel {
   Q_OBJECT
 
  public:
-  explicit PlaylistListSortFilterModel(QObject *parent)
-      : QSortFilterProxyModel(parent) {}
+  explicit PlaylistListSortFilterModel(QObject *parent);
 
-  bool lessThan(const QModelIndex &left, const QModelIndex &right) const override {
-    // Compare the display text first.
-    const int ret = left.data().toString().localeAwareCompare(right.data().toString());
-    if (ret < 0) return true;
-    if (ret > 0) return false;
-
-    // Now use the source model row order to ensure we always get a deterministic sorting even when two items are named the same.
-    return left.row() < right.row();
-  }
+  bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 };
 
 #endif  // PLAYLISTLISTSORTFILTERMODEL_H
