@@ -58,6 +58,7 @@
 #include <QScrollBar>
 #include <QtEvents>
 #include <QSettings>
+#include <QDrag>
 
 #include "includes/qt_blurimage.h"
 #include "core/song.h"
@@ -690,12 +691,6 @@ void PlaylistView::showEvent(QShowEvent *e) {
 
 }
 
-namespace {
-bool CompareSelectionRanges(const QItemSelectionRange &a, const QItemSelectionRange &b) {
-  return b.bottom() < a.bottom();
-}
-}  // namespace
-
 void PlaylistView::keyPressEvent(QKeyEvent *event) {
 
   if (!model() || state() == QAbstractItemView::EditingState) {
@@ -758,7 +753,7 @@ void PlaylistView::RemoveSelected() {
   int last_row = selection.last().top();
 
   // Sort the selection, so we remove the items at the *bottom* first, ensuring we don't have to mess around with changing row numbers
-  std::sort(selection.begin(), selection.end(), CompareSelectionRanges);
+  std::sort(selection.begin(), selection.end(), [](const QItemSelectionRange &a, const QItemSelectionRange &b) { return b.bottom() < a.bottom(); });
 
   for (const QItemSelectionRange &range : selection) {
     if (range.top() < last_row) rows_removed += range.height();
@@ -1376,8 +1371,9 @@ void PlaylistView::rowsInserted(const QModelIndex &parent, const int start, cons
 
   QTreeView::rowsInserted(parent, start, end);
 
-  if (at_end) {
+  if (at_end && playlist_ && !playlist_->is_dynamic()) {
     // If the rows were inserted at the end of the playlist then let's scroll the view so the user can see.
+    // However, don't do this for dynamic playlists as they continuously add items at the end, and we want to keep the current playing track visible instead.
     scrollTo(model()->index(start, 0, parent), QAbstractItemView::PositionAtTop);
   }
 
@@ -1451,9 +1447,9 @@ void PlaylistView::SongChanged(const Song &song) {
   song_playing_ = song;
 
   if (select_track_ && playlist_) {
-    clearSelection();
-    QItemSelection selection(playlist_->index(playlist_->current_row(), 0), playlist_->index(playlist_->current_row(), Playlist::ColumnCount - 1));
-    selectionModel()->select(selection, QItemSelectionModel::Select);
+    const QModelIndex current_index = playlist_->filter()->mapFromSource(playlist_->index(playlist_->current_row(), 0));
+    if (!current_index.isValid()) return;
+    selectionModel()->setCurrentIndex(current_index, QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows);
   }
 
 }
@@ -1626,3 +1622,11 @@ void PlaylistView::RatingHoverOut() {
   }
 
 }
+
+void PlaylistView::startDrag(const Qt::DropActions drop_actions) {
+
+  QDrag *drag = new QDrag(this);
+  drag->setMimeData(model()->mimeData(selectedIndexes()));
+  drag->exec(drop_actions, Qt::CopyAction);
+
+}
