@@ -27,7 +27,6 @@
 #include <QString>
 
 #include "includes/shared_ptr.h"
-#include "dialogs/errordialog.h"
 #include "settingspage.h"
 
 class SettingsDialog;
@@ -80,7 +79,6 @@ class BackendSettingsPage : public SettingsPage {
   const SharedPtr<DeviceFinders> device_finders_;
 
   bool configloaded_;
-  ErrorDialog errordialog_;
 
   QString output_current_;
   QVariant device_current_;
