@@ -23,12 +23,11 @@
 #include <QObject>
 #include <QWizard>
 
-#include "core/shared_ptr.h"
+#include "includes/shared_ptr.h"
 #include "smartplaylistwizardplugin.h"
 
-SmartPlaylistWizardPlugin::SmartPlaylistWizardPlugin(Application *app, SharedPtr<CollectionBackend> collection_backend, QObject *parent)
+SmartPlaylistWizardPlugin::SmartPlaylistWizardPlugin(const SharedPtr<CollectionBackend> collection_backend, QObject *parent)
     : QObject(parent),
-      app_(app),
       collection_backend_(collection_backend),
       start_page_(-1) {}
 
