@@ -26,11 +26,7 @@ namespace Utilities {
 
 QString ColorToRgba(const QColor &c) {
 
-  return QStringLiteral("rgba(%1, %2, %3, %4)")
-      .arg(c.red())
-      .arg(c.green())
-      .arg(c.blue())
-      .arg(c.alpha());
+  return QStringLiteral("rgba(%1, %2, %3, %4)").arg(c.red()).arg(c.green()).arg(c.blue()).arg(c.alpha());
 
 }
 
