@@ -77,9 +77,9 @@ class PlayingWidget : public QWidget {
 
  protected:
   void paintEvent(QPaintEvent *e) override;
-  void resizeEvent(QResizeEvent*) override;
+  void resizeEvent(QResizeEvent *e) override;
   void contextMenuEvent(QContextMenuEvent *e) override;
-  void mouseDoubleClickEvent(QMouseEvent*) override;
+  void mouseDoubleClickEvent(QMouseEvent *e) override;
   void dragEnterEvent(QDragEnterEvent *e) override;
   void dropEvent(QDropEvent *e) override;
 
@@ -136,7 +136,6 @@ class PlayingWidget : public QWidget {
   void DrawContents(QPainter *p);
   void ScaleCover();
   void GetCoverAutomatically();
-
 };
 
 #endif  // PLAYINGWIDGET_H
