@@ -26,13 +26,11 @@ THE SOFTWARE.
 #include <QString>
 #include <QImage>
 #include <QPixmap>
-#include <QBoxLayout>
-#include <QMacCocoaViewContainer>
 
-static inline NSString* fromQString(const QString &string) {
+static inline NSString *fromQString(const QString &string) {
 
   const QByteArray utf8 = string.toUtf8();
-  const char* cString = utf8.constData();
+  const char *cString = utf8.constData();
   return [ [NSString alloc] initWithUTF8String:cString];
 
 }
@@ -44,19 +42,10 @@ static inline QString toQString(NSString *string) {
 
 }
 
-static inline NSImage* fromQPixmap(const QPixmap &pixmap) {
+static inline NSImage *fromQPixmap(const QPixmap &pixmap) {
 
   QImage image = pixmap.toImage();
   CGImageRef cgImage = image.toCGImage();
   return [ [NSImage alloc] initWithCGImage:cgImage size:NSZeroSize];
 
 }
-
-static inline void setupLayout(NSView *cocoaView, QWidget *parent) {
-
-  parent->setAttribute(Qt::WA_NativeWindow);
-  QVBoxLayout *layout = new QVBoxLayout(parent);
-  layout->setMargin(0);
-  layout->addWidget(new QMacCocoaViewContainer(cocoaView, parent));
-
-}
