@@ -32,12 +32,16 @@ class ResizableTextEdit : public QTextEdit {
 
   virtual QSize sizeHint() const override;
 
+  QString text() const { return Text(); }
+  QString Text() const { return text_; }
   void setText(const QString &text) { SetText(text); }
   void SetText(const QString &text);
 
  protected:
   virtual void resizeEvent(QResizeEvent *event) override;
 
+ private:
+  QString text_;
 };
 
 #endif  // RESIZABLETEXTEDIT_H
